=============================
 Support for Version Control
=============================

|PD| supports several version control systems by default, and more can be
added (see :doc:`config` for details).  By 'support', this means that when
|PD| adds or removes an issue file (via the :kbd:`add`, :kbd:`drop` or
:kbd:`archive` commands), it also runs the appropriate VCS command to add
or remove the file.  Of course, you will have to commit the changes made
yourself.

